<?php
/* $Id: ukrainian-windows-1251.inc.php,v 2.65 2005/03/30 19:25:46 lem9 Exp $ */

$charset = 'windows-1251';
$text_dir = 'ltr';
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
//$byteUnits = array('', '', '', '');
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('', '', '', '', '', '', '');
$month = array('ѳ', '', '', '', '', '', '', '', '', '', '', '');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%B %d %Y ., %H:%M';

$timespanfmt = '%s , %s , %s   %s ';

$strAPrimaryKey = '     %s';
$strAbortedClients = '';
$strAbsolutePathToDocSqlDir = '     -   docSQL';
$strAccessDenied = ' ';
$strAccessDeniedExplanation = 'phpMyAdmin  \'  MySQL ,     \'.    host, username  password   config.inc.php  ,         MySQL .';
$strAction = 'ĳ';
$strAddDeleteColumn = '/  ';
$strAddDeleteRow = '/  ';
$strAddDropDatabase = ' DROP DATABASE';
$strAddIntoComments = ' ';
$strAddNewField = '  ';
$strAddPrivilegesOnDb = '     ';
$strAddPrivilegesOnTbl = '    ';
$strAddSearchConditions = '   (   "where"):';
$strAddToIndex = '  &nbsp;%s&nbsp;()';
$strAddUser = '  ';
$strAddUserMessage = '   .';
$strAddedColumnComment = '   ';
$strAddedColumnRelation = ' \'  ';
$strAdministration = '';
$strAffectedRows = ' :';
$strAfter = 'ϳ %s';
$strAfterInsertBack = '';
$strAfterInsertNewInsert = '  ';
$strAll = '';
$strAllTableSameWidth = '    ?';
$strAlterOrderBy = '  ';
$strAnIndex = '    %s';
$strAnalyzeTable = ' ';
$strAnd = '';
$strAny = '';
$strAnyHost = ' ';
$strAnyUser = ' ';
$strArabic = '';
$strArmenian = '³';
$strAscending = '';
$strAtBeginningOfTable = '  ';
$strAtEndOfTable = '  ';
$strAttr = '';
$strAutodetect = '';
$strAutomaticLayout = ' layout';

$strBack = '';
$strBaltic = '';
$strBeginCut = 'BEGIN CUT';
$strBeginRaw = 'BEGIN RAW';
$strBinary = '  ';
$strBinaryDoNotEdit = '   -   ';
$strBookmarkDeleted = '  .';
$strBookmarkLabel = '̳';
$strBookmarkQuery = '  SQL-';
$strBookmarkThis = '   SQL-';
$strBookmarkView = ' ';
$strBrowse = '';
$strBulgarian = '';
$strBzError = 'phpMyAdmin    dump   Bz2     PHP.        phpMyAdmin  <code>$cfg[\'BZipDump\']</code>  <code>FALSE</code>.      Bz2 ,     PHP. .      %s.';
$strBzip = '  "bzip"';

$strCSVOptions = 'CSV ';
$strCannotLogin = '    MySQL ';
$strCantLoad = '   %s,<br />   PHP.';
$strCantLoadRecodeIconv = '   iconv  recode extension    charset-,  php ,      extensions,    charset-  phpMyAdmin.';
$strCantRenameIdxToPrimary = '    PRIMARY!';
$strCantUseRecodeIconv = '    / iconv, / libiconv, /  recode_string    extension reports.   php .';
$strCardinality = 'ʳ ';
$strCarriage = ' : \\r';
$strCaseInsensitive = 'case-insensitive';
$strCaseSensitive = 'case-sensitive';
$strCentralEuropean = '';
$strChange = '';
$strChangeCopyMode = '        ...';
$strChangeCopyModeCopy = '...  .';
$strChangeCopyModeDeleteAndReload = ' ...          .';
$strChangeCopyModeJustDelete = ' ...     .';
$strChangeCopyModeRevoke = ' ...      ,    .';
$strChangeCopyUser = '   /  ';
$strChangeDisplay = '   ';
$strChangePassword = ' ';
$strCharset = ' ';
$strCharsetOfFile = ' :';
$strCharsets = '';
$strCharsetsAndCollations = '   ';
$strCheckAll = '³ ';
$strCheckPrivs = ' ';
$strCheckPrivsLong = '     &quot;%s&quot;.';
$strCheckTable = ' ';
$strChoosePage = '    ';
$strColComFeat = '  ';
$strCollation = '';
$strColumnNames = ' ';
$strColumnPrivileges = ',    ';
$strCommand = '';
$strComments = '';
$strCompleteInserts = ' ';
$strCompression = '';
$strConfigFileError = 'phpMyAdmin      <br />     ,  php     (parse error)  ,      .<br />               (php error messages).         .  <br />    , -    .';
$strConfigureTableCoord = '    %s';
$strConnections = '\'';
$strCookiesRequired = '   Cookies   .';
$strCopyTable = '   ( <b>.</b>):';
$strCopyTableOK = ' %s    %s.';
$strCopyTableSameNames = '      !';
$strCouldNotKill = 'phpMyAdmin     %s. ³    .';
$strCreate = '';
$strCreateIndex = '  &nbsp;%s&nbsp;';
$strCreateIndexTopic = '  ';
$strCreateNewDatabase = '  ';
$strCreateNewTable = '     %s';
$strCreatePage = '  ';
$strCreatePdfFeat = ' PDF-';
$strCriteria = '';
$strCroatian = '';
$strCyrillic = '';
$strCzech = '';

$strDBComment = '  : ';
$strDBGContext = '';
$strDBGContextID = ' ID';
$strDBGHits = 'Hits';
$strDBGLine = '';
$strDBGMaxTimeMs = ' , ';
$strDBGMinTimeMs = '̳ , ';
$strDBGModule = '';
$strDBGTimePerHitMs = 'Time/Hit, ';
$strDBGTotalTimeMs = ' , ';
$strDanish = '';
$strData = '';
$strDataDict = ' ';
$strDataOnly = ' ';
$strDatabase = '';
$strDatabaseExportOptions = '   ';
$strDatabaseHasBeenDropped = '  %s .';
$strDatabaseNoTable = '     !';
$strDatabases = ' ';
$strDatabasesDropped = '%s (\)   .';
$strDatabasesStats = '  ';
$strDatabasesStatsDisable = ' ';
$strDatabasesStatsEnable = ' ';
$strDatabasesStatsHeavyTraffic = ':                MySQL.';
$strDbPrivileges = ',    ';
$strDbSpecific = '   ';
$strDefault = ' ';
$strDefaultValueHelp = '   ,   ,      ,   : a';
$strDelOld = '     ,   .    ?';
$strDelete = '';
$strDeleteAndFlush = '      .';
$strDeleteAndFlushDescr = '  ,       .';
$strDeleted = ' ';
$strDeletedRows = '  :';
$strDeleting = ' %s';
$strDescending = '';
$strDescription = '';
$strDictionary = '';
$strDisabled = '';
$strDisplayFeat = ' ';
$strDisplayOrder = ' :';
$strDisplayPDF = ' PDF ';
$strDoAQuery = ' "  " ( : "%")';
$strDoYouReally = '   ';
$strDocu = '';
$strDrop = '';
$strDropSelectedDatabases = '   ';
$strDropUsersDb = '  ,        .';
$strDumpSaved = 'Dump    %s.';
$strDumpXRows = 'Ǵ  %s    %s -.';
$strDumpingData = '  ';
$strDynamic = '';

$strEdit = '';
$strEditPDFPages = ' PDF ';
$strEditPrivileges = ' ';
$strEffective = '';
$strEmpty = '';
$strEmptyResultSet = 'MySQL    (  ).';
$strEnabled = '';
$strEnd = 'ʳ';
$strEndCut = 'END CUT';
$strEndRaw = 'END RAW';
$strEnglish = '';
$strEnglishPrivileges = ' :  MySQL  - ';
$strError = '';
$strEstonian = '';
$strExcelOptions = ' Excel';
$strExecuteBookmarked = '  ';
$strExplain = ' SQL';
$strExport = '';
$strExtendedInserts = ' ';
$strExtra = '';

$strFailedAttempts = ' ';
$strField = '';
$strFieldHasBeenDropped = ' %s  ';
$strFields = '';
$strFieldsEmpty = '   ! ';
$strFieldsEnclosedBy = '  ';
$strFieldsEscapedBy = ' ';
$strFieldsTerminatedBy = ' ';
$strFileAlreadyExists = ' %s   ,    ,      .';
$strFileCouldNotBeRead = '  ';
$strFileNameTemplate = '  ';
$strFileNameTemplateHelp = ' __DB__    , __TABLE__     %s strftime%s     ,    . -    .';
$strFileNameTemplateRemember = '\' ';
$strFixed = '';
$strFlushPrivilegesNote = ': phpMyAdmin        MySQL.       ,   ,       .      %s %s  .';
$strFlushTable = '   ("FLUSH")';
$strFormEmpty = '    !';
$strFormat = '';
$strFullText = ' ';
$strFunction = '';

$strGenBy = '';
$strGenTime = ' ';
$strGeneralRelationFeat = ' ';
$strGerman = 'ͳ';
$strGlobal = '';
$strGlobalPrivileges = ' ';
$strGlobalValue = ' ';
$strGo = '';
$strGrantOption = 'Grant';
$strGreek = '';
$strGzip = '  "gzip"';

$strHasBeenAltered = ' .';
$strHasBeenCreated = ' .';
$strHaveToShow = '      ';
$strHebrew = '';
$strHome = ' ';
$strHomepageOfficial = '  phpMyAdmin';
$strHost = '';
$strHostEmpty = ' \' !';
$strHungarian = '';

$strId = 'ID';
$strIdxFulltext = '';
$strIfYouWish = '       ,     .';
$strIgnore = '';
$strIgnoringFile = '  %s';
$strImportDocSQL = ' docSQL ';
$strImportFiles = ' ';
$strImportFinished = ' ';
$strInUse = '';
$strIndex = '';
$strIndexHasBeenDropped = ' %s  ';
$strIndexName = ' &nbsp;:';
$strIndexType = ' &nbsp;:';
$strIndexes = '';
$strInnodbStat = ' InnoDB';
$strInsecureMySQL = '     (root  )     MySQL.  MySQL           \'      .';
$strInsert = '';
$strInsertAsNewRow = '   ';
$strInsertNewRow = '  ';
$strInsertTextfiles = '    ';
$strInsertedRowId = '  id:';
$strInsertedRows = ' :';
$strInstructions = '';

$strJapanese = '';
$strJumpToDB = '    &quot;%s&quot;.';
$strJustDelete = '     .';
$strJustDeleteDescr = '&quot;&quot;          ,     .';

$strKeepPass = '  ';
$strKeyname = '\' ';
$strKill = '';
$strKorean = '';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = ' LaTeX';
$strLandscape = 'Landscape';
$strLengthSet = '/*';
$strLimitNumRows = '  ';
$strLineFeed = '  : \\n';
$strLinesTerminatedBy = ' ';
$strLinkNotFound = '˳  ';
$strLinksTo = '˳ ';
$strLithuanian = '';
$strLoadExplanation = '    ,     ,    .';
$strLoadMethod = ' ';
$strLocalhost = '';
$strLocationTextfile = '   ';
$strLogPassword = ':';
$strLogUsername = '\' :';
$strLogin = '  ';
$strLoginInformation = '  (Login)';
$strLogout = '  ';

$strMIME_MIMEtype = 'MIME-type';
$strMIME_available_mime = ' MIME-types';
$strMIME_available_transform = ' ';
$strMIME_description = '';
$strMIME_nodescription = '    .<br />  ,   %s.';
$strMIME_transformation = ' ̲- ';
$strMIME_transformation_note = '       MIME-type ,  %s %s';
$strMIME_transformation_options = ' ';
$strMIME_transformation_options_note = '       : \'a\',\'b\',\'c\'...<br />     ("\")    ("\'")   ,       ( \'\\\\xyz\'  \'a\\\'b\').';
$strMIME_without = 'MIME-types       ';
$strModifications = '  ';
$strModify = '';
$strModifyIndexTopic = ' ';
$strMoreStatusVars = '  ';
$strMoveTable = '   ( <b>.</b>):';
$strMoveTableOK = ' %s    %s.';
$strMoveTableSameNames = '      !';
$strMultilingual = '';
$strMustSelectFile = '  ,    .';
$strMySQLCharset = 'MySQL Charset';
$strMySQLReloaded = 'MySQL .';
$strMySQLSaid = '³ MySQL: ';
$strMySQLServerProcess = 'MySQL %pma_s1%  %pma_s2%  %pma_s3%';
$strMySQLShowProcess = ' ';
$strMySQLShowStatus = '  MySQL';
$strMySQLShowVars = '   MySQL';

$strName = '';
$strNext = '';
$strNo = 'ͳ';
$strNoDatabases = ' ';
$strNoDatabasesSelected = '   .';
$strNoDescription = ' ';
$strNoDropDatabases = ' "DROP DATABASE" .';
$strNoExplain = '  SQL';
$strNoFrames = '  phpMyAdmin     <b></b>.';
$strNoIndex = '  !';
$strNoIndexPartsDefined = '   !';
$strNoModification = ' ';
$strNoOptions = '    ';
$strNoPassword = ' ';
$strNoPermission = '-       %s.';
$strNoPhp = ' PHP ';
$strNoPrivileges = ' ';
$strNoQuery = '  SQL-!';
$strNoRights = '     !';
$strNoSpace = '     %s.';
$strNoTablesFound = '    .';
$strNoUsersFound = '  .';
$strNoValidateSQL = '  SQL';
$strNone = '';
$strNotNumber = '  !';
$strNotOK = ' OK';
$strNotSet = ' <b>%s</b>       %s';
$strNotValidNumber = '   !';
$strNull = '';
$strNumSearchResultsInTable = '%s    <i>%s</i>';
$strNumSearchResultsTotal = '<b>:</b> <i>%s</i> ';
$strNumTables = '';

$strOK = 'OK';
$strOftenQuotation = ' .   ,    char  varchar   .';
$strOperations = '';
$strOptimizeTable = ' ';
$strOptionalControls = ' .      .';
$strOptionally = ' ';
$strOr = '';
$strOverhead = ' ';
$strOverwriteExisting = '  ';

$strPHP40203 = '   PHP 4.2.3,        multi-byte strings (mbstring).  PHP bug report 19404.   PHP     phpMyAdmin.';
$strPHPVersion = ' PHP';
$strPageNumber = ' :';
$strPaperSize = ' ';
$strPartialText = ' ';
$strPassword = '';
$strPasswordChanged = '  %s  .';
$strPasswordEmpty = ' !';
$strPasswordNotSame = '  !';
$strPdfDbSchema = '   "%s" -  %s';
$strPdfInvalidTblName = ' "%s"  !';
$strPdfNoTables = ' ';
$strPerHour = ' ';
$strPerMinute = ' ';
$strPerSecond = ' ';
$strPhoneBook = ' ';
$strPhp = ' PHP ';
$strPmaDocumentation = '  phpMyAdmin';
$strPmaUriError = ' <tt>$cfg[\'PmaAbsoluteUri\']</tt>       !';
$strPortrait = 'Portrait';
$strPos1 = '';
$strPrevious = '';
$strPrimary = '';
$strPrimaryKeyHasBeenDropped = '   ';
$strPrimaryKeyName = '\'     PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b></b>   <b></b>  !)';
$strPrint = '';
$strPrintView = '  ';
$strPrivDescAllPrivileges = '     GRANT.';
$strPrivDescAlter = '    .';
$strPrivDescCreateDb = '      .';
$strPrivDescCreateTbl = '   .';
$strPrivDescCreateTmpTable = '   .';
$strPrivDescDelete = '    .';
$strPrivDescDropDb = '     .';
$strPrivDescDropTbl = '  .';
$strPrivDescExecute = '   ;     MySQL.';
$strPrivDescFile = '    ,    .';
$strPrivDescGrant = '        .';
$strPrivDescIndex = '    .';
$strPrivDescInsert = '    .';
$strPrivDescLockTables = '     .';
$strPrivDescMaxConnections = '   \',      .';
$strPrivDescMaxQuestions = '  ,       .';
$strPrivDescMaxUpdates = '  ,     -    ,      .';
$strPrivDescProcess3 = '    .';
$strPrivDescProcess4 = '      .';
$strPrivDescReferences = '    MySQL.';
$strPrivDescReload = '      .';
$strPrivDescReplClient = '      slaves / masters.';
$strPrivDescReplSlave = '   slaves.';
$strPrivDescSelect = '  .';
$strPrivDescShowDb = '      .';
$strPrivDescShutdown = '  .';
$strPrivDescSuper = ' \',      \'; \'              .';
$strPrivDescUpdate = '  .';
$strPrivDescUsage = ' .';
$strPrivileges = '';
$strPrivilegesReloaded = '  .';
$strProcesslist = ' ';
$strPutColNames = '     ';

$strQBE = '  ';
$strQBEDel = '';
$strQBEIns = '';
$strQueryFrame = '³ ';
$strQueryOnDb = 'SQL-   <b>%s</b>:';
$strQuerySQLHistory = 'SQL-history';
$strQueryStatistics = '<b> </b>:   ,     %s .';
$strQueryTime = '  %01.4f ';
$strQueryType = ' ';
$strQueryWindowLock = '      ';

$strReType = 'ϳ';
$strReceived = '';
$strRecords = '';
$strReferentialIntegrity = '     :';
$strRelationNotWorking = '      .  ,   ,  %s%s.';
$strRelationView = ' ';
$strRelationalSchema = ' \'';
$strRelations = '\'';
$strReloadFailed = '   MySQL.';
$strReloadMySQL = ' MySQL';
$strReloadingThePrivileges = ' ';
$strRemoveSelectedUsers = '  ';
$strRenameTable = '  ';
$strRenameTableOK = ' %s    %s';
$strRepairTable = ' ';
$strReplace = '';
$strReplaceNULLBy = ' NULL ';
$strReplaceTable = '     ';
$strReset = '';
$strResourceLimits = ' ';
$strRevoke = '³';
$strRevokeAndDelete = '³         .';
$strRevokeAndDeleteDescr = '       (USAGE)   ,     .';
$strRevokeMessage = '    %s';
$strRowLength = ' ';
$strRowSize = '   ';
$strRows = '';
$strRowsFrom = ' ';
$strRowsModeFlippedHorizontal = ' (rotated headers)';
$strRowsModeHorizontal = '  ';
$strRowsModeOptions = '- %s      %s  ';
$strRowsModeVertical = '  ';
$strRowsStatistic = ' ';
$strRunQuery = ' ';
$strRunSQLQuery = ' SQL ()   %';
$strRunning = ' %s';
$strRussian = '';

$strSQL = 'SQL';
$strSQLOptions = 'SQL ';
$strSQLParserBugMessage = '      SQL.             .                    .        MySQL   .  MySQL      (  )       .           ,      ,     SQL    ,     ,           CUT :';
$strSQLParserUserError = 'There seems to be an error in your SQL query.  MySQL      (  )       .';
$strSQLQuery = 'SQL-';
$strSQLResult = 'SQL result';
$strSQPBugInvalidIdentifer = ' ';
$strSQPBugUnclosedQuote = '  ';
$strSQPBugUnknownPunctuation = '  ';
$strSave = '';
$strSaveOnServer = '     %s ';
$strScaleFactorSmall = '       ';
$strSearch = '';
$strSearchFormTitle = '   ';
$strSearchInTables = ' :';
$strSearchNeedle = '  ,    (: "%"):';
$strSearchOption1 = '   ';
$strSearchOption2 = ' ';
$strSearchOption3 = ' ';
$strSearchOption4 = ' ';
$strSearchResultsFor = '  "<i>%s</i>" %s:';
$strSearchType = ':';
$strSecretRequired = '     ().';
$strSelectADb = '  ';
$strSelectAll = '³ ';
$strSelectFields = '  ( ):';
$strSelectNumRows = ' ';
$strSelectTables = ' ';
$strSend = '³';
$strSent = '³';
$strServer = '';
$strServerChoice = ' ';
$strServerStatus = '   ';
$strServerStatusUptime = ' MySQL   %s.  %s.';
$strServerTabProcesslist = '';
$strServerTabVariables = '';
$strServerTrafficNotes = '<b> </b>:       MySQL     .';
$strServerVars = '   ';
$strServerVersion = ' ';
$strSessionValue = ' ';
$strSetEnumVal = '   "enum"  "set",     : \'a\',\'b\',\'c\'...<br />        ("\"")    ("\'")   ,       (, \'\\\\xyz\'  \'a\\\'b\').';
$strShow = '';
$strShowAll = ' ';
$strShowColor = ' ';
$strShowDatadictAs = ' ';
$strShowFullQueries = '  ';
$strShowGrid = ' ';
$strShowPHPInfo = '   PHP';
$strShowTableDimension = '  ';
$strShowTables = ' ';
$strShowThisQuery = '     ';
$strShowingRecords = '  ';
$strSimplifiedChinese = ' ';
$strSingly = '()';
$strSize = '';
$strSort = '';
$strSpaceUsage = ',  ';
$strSplitWordsWithSpace = '   (" ").';
$strStatCheckTime = '';
$strStatCreateTime = '';
$strStatUpdateTime = '';
$strStatement = '';
$strStatus = '';
$strStrucCSV = 'CSV ';
$strStrucData = '  ';
$strStrucDrop = '  ';
$strStrucExcelCSV = 'CSV   MS Excel';
$strStrucOnly = ' ';
$strStructPropose = '  ';
$strStructure = '';
$strSubmit = '';
$strSuccess = ' SQL-   ';
$strSum = '';
$strSwedish = '';
$strSwitchToTable = '   ';

$strTable = ' ';
$strTableComments = '  ';
$strTableEmpty = '  !';
$strTableHasBeenDropped = ' %s  ';
$strTableHasBeenEmptied = ' %s  ';
$strTableHasBeenFlushed = '    %s';
$strTableMaintenance = ' ';
$strTableOfContents = '';
$strTableOptions = ' ';
$strTableStructure = ' ';
$strTableType = ' ';
$strTables = '%s ()';
$strTblPrivileges = ',   ';
$strTextAreaLength = '   ,<br />       ';
$strThai = '';
$strTheContent = '   .';
$strTheContents = '            .';
$strTheTerminator = '  .';
$strThisHost = ' ';
$strThisNotDirectory = '  ';
$strThreadSuccessfullyKilled = ' %s .';
$strTime = '';
$strToggleScratchboard = '  (scratchboard)';
$strTotal = '';
$strTotalUC = '';
$strTraditionalChinese = ' ';
$strTraffic = '';
$strTransformation_image_jpeg__inline = '³ clickable thumbnail; : ,    (  )';
$strTransformation_image_jpeg__link = '³     (direct blob download, i.e.).';
$strTransformation_image_png__inline = '. image/jpeg: inline';
$strTransformation_text_plain__dateformat = '  TIME, TIMESTAMP  DATETIME        .   -   ( )       ( : 0).   -         PHP strftime().';
$strTransformation_text_plain__external = 'LINUX ONLY:         .    .     Tidy,    HTML .   ,      libraries/transformations/text_plain__external.inc.php      .   ,   -  ,       -   .  ,   1,     htmlspecialchars() ( : 1).  ,   1,   NOWRAP    ,         ( : 1)';
$strTransformation_text_plain__formatted = '   .   .';
$strTransformation_text_plain__imagelink = '   ,    ;   - ,   "http://domain.com/",  -   ,  - .';
$strTransformation_text_plain__link = ' ,    ;   - ,   "http://domain.com/",   - title  .';
$strTransformation_text_plain__substr = '   .   -            ( : 0).   -     .    -    .   -          ( : ...) .';
$strTruncateQueries = '  ';
$strTurkish = '';
$strType = '';

$strUkrainian = '';
$strUncheckAll = '  ';
$strUnicode = '';
$strUnique = '';
$strUnknown = '';
$strUnselectAll = '  ';
$strUpdComTab = '      Column_comments    ';
$strUpdatePrivMessage = '   ';
$strUpdateProfileMessage = '  .';
$strUpdateQuery = ' ';
$strUsage = '';
$strUseBackquotes = '      ';
$strUseHostTable = '  ';
$strUseTables = ' ';
$strUseTextField = '  ';
$strUser = '';
$strUserAlreadyExists = ' %s  !';
$strUserEmpty = ' \' !';
$strUserName = '\' ';
$strUserNotFound = '      .';
$strUserOverview = ' ';
$strUsersDeleted = '³   .';
$strUsersHavingAccessToDb = ',     &quot;%s&quot;';

$strValidateSQL = ' SQL';
$strValidatorError = '    SQL.      php extensions    %s%s.';
$strValue = '';
$strVar = '';
$strViewDump = '  () ';
$strViewDumpDB = '  () ';
$strViewDumpDatabases = ' dump ()  ';

$strWebServerUploadDirectory = ' -    (upload directory)';
$strWebServerUploadDirectoryError = '      ';
$strWelcome = '   %s';
$strWestEuropean = ' ';
$strWildcard = '';
$strWithChecked = ' :';
$strWritingCommentNotPossible = '  ';
$strWritingRelationNotPossible = '  \'';
$strWrongUser = ' /.   .';

$strXML = 'XML';

$strYes = '';

$strZeroRemovesTheLimit = ':     0 ()  .';
$strZip = '  "zip"';
// To translate

$strAddAutoIncrement = 'Add AUTO_INCREMENT value';  //to translate

$strUseThisValue = 'Use this value';  //to translate
$strWindowNotFound = 'The target browser window could not be updated. Maybe you have closed the parent window or your browser is blocking cross-window updates of your security settings';  //to translate
$strBrowseForeignValues = 'Browse foreign values';  //to translate
$strInternalRelations = 'Internal relations';  //to translate
$strInternalNotNecessary = '* An internal relation is not necessary when it exists also in InnoDB.';  //to translate
$strUpgrade = 'You should upgrade to %s %s or later.';  //to translate
$strLatexStructure = 'Structure of table __TABLE__';//to translate
$strLatexContinued = '(continued)';//to translate
$strLatexContent = 'Content of table __TABLE__';//to translate
$strLatexIncludeCaption = 'Include table caption';//to translate
$strLatexCaption = 'Table caption';//to translate
$strLatexLabel = 'Label key';//to translate
$strLatexContinuedCaption = 'Continued table caption';//to translate

$strPrintViewFull = 'Print view (with full texts)';  //to translate
$strLogServer = 'Server';  //to translate
$strSortByKey = 'Sort by key';  //to translate
$strBookmarkAllUsers = 'Let every user access this bookmark';  //to translate
$strConstraintsForDumped = 'Constraints for dumped tables';  //to translate
$strConstraintsForTable = 'Constraints for table';  //to translate
$strBookmarkOptions = 'Bookmark options';  //to translate
$strCreationDates = 'Creation/Update/Check dates';  //to translate
$strCheckOverhead = 'Check tables with overhead';  //to translate
$strExcelEdition = 'Excel edition';  //to translate
$strDelayedInserts = 'Use delayed inserts';  //to translate
$strSQLExportType = 'Export type';  //to translate
$strAddConstraints = 'Add constraints';  //to translate
$strGeorgian = 'Georgian';  //to translate
$strCzechSlovak = 'Czech-Slovak';  //to translate
$strTransformation_application_octetstream__download = 'Display a link to download the binary data of a field. First option is the filename of the binary file. Second option is a possible fieldname of a table row containing the filename. If you provide a second option you need to have the first option set to an empty string';  //to translate
$strMaximumSize = 'Maximum size: %s%s';  //to translate
$strConnectionError = 'Cannot connect: invalid settings.';  //to translate
$strDropDatabaseStrongWarning = 'You are about to DESTROY a complete database!';  //to translate
$strAddHeaderComment = 'Add custom comment into header (\\n splits lines)';  //to translate
$strNeedPrimaryKey = 'You should define a primary key for this table.';  //to translate
$strIgnoreInserts = 'Use ignore inserts';  //to translate
$strAddIfNotExists = 'Add IF NOT EXISTS';  //to translate
$strCommentsForTable = 'COMMENTS FOR TABLE';  //to translate
$strMIMETypesForTable = 'MIME TYPES FOR TABLE';  //to translate
$strRelationsForTable = 'RELATIONS FOR TABLE';  //to translate
$strAfterInsertSame = 'Go back to this page';  //to translate
$strRenameDatabaseOK = 'Database %s has been renamed to %s';  //to translate
$strDatabaseEmpty = 'The database name is empty!';  //to translate
$strDBRename = 'Rename database to';  //to translate
$strOperator = 'Operator';  //to translate
$strEncloseInTransaction = 'Enclose export in a transaction';  //to translate
$strCalendar = 'Calendar';  //to translate
$strRefresh = 'Refresh';  //to translate
$strDefragment = 'Defragment table';  //to translate
$strNoRowsSelected = 'No rows selected';  //to translate
$strSpanish = 'Spanish';  //to translate
$strStrucNativeExcel = 'Native MS Excel data';  //to translate
$strDisableForeignChecks = 'Disable foreign key checks';  //to translate
$strServerNotResponding = 'The server is not responding';  //to translate
$strTheme = 'Theme / Style';  //to translate
$strTakeIt = 'take it';  //to translate
$strHexForBinary = 'Use hexadecimal for binary fields';  //to translate
$strIcelandic = 'Icelandic';  //to translate
$strLatvian = 'Latvian';  //to translate
$strPolish = 'Polish';  //to translate
$strRomanian = 'Romanian';  //to translate
$strSlovenian = 'Slovenian';  //to translate
$strTraditionalSpanish = 'Traditional Spanish';  //to translate
$strSlovak = 'Slovak';  //to translate
$strMySQLConnectionCollation = 'MySQL connection collation';  //to translate
$strPersian = 'Persian';  //to translate
$strAddFields = 'Add %s field(s)';  //to translate
$strInsertBookmarkTitle = 'Please insert bookmark title';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogEventType = 'Event type';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogInfo = 'Information';  //to translate
$strBinaryLog = 'Binary log';  //to translate
$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strDBCopy = 'Copy database to';  //to translate
$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
$strSwitchToDatabase = 'Switch to copied database';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strAfterInsertNext = 'Edit next row';  //to translate
$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strEngines = 'Engines';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
$strVersionInformation = 'Version information';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
?>
